#
# spec file for package Radicale
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012-2024 Ákos Szőts <szotsaki@gmail.com>
# Copyright (c) 2011 Marcus Rueckert <darix@opensu.se>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_name       radicale
%define pkg_config     %{_sysconfdir}/%{pkg_name}
%define pkg_home       %{_localstatedir}/lib/%{pkg_name}
%define pkg_user_group %{pkg_name}
%define py_min_ver 3.8
%define vo_min_ver 0.9.6
%define pk_min_ver 1.1.0
Name:           Radicale
Version:        3.3.1
Release:        1.1
Summary:        A CalDAV calendar and CardDav contact server
License:        GPL-3.0-or-later
Group:          Productivity/Office/Other
URL:            https://www.radicale.org/
Source:         https://github.com/Kozea/Radicale/archive/v%{version}.tar.gz
Source1:        radicale.service
Source2:        system-user-%{pkg_user_group}.conf
Source3:        radicale.firewalld
Source4:        %{name}.rpmlintrc
BuildRequires:  fdupes
BuildRequires:  firewall-macros
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3-setuptools
BuildRequires:  systemd-rpm-macros
BuildRequires:  sysuser-tools
BuildRequires:  pkgconfig(python3) >= %{py_min_ver}
Requires:       python3 >= %{py_min_ver}
Requires:       python3-defusedxml
Requires:       python3-passlib
Requires:       python3-pika >= %{pk_min_ver}
Requires:       python3-vobject >= %{vo_min_ver}
Recommends:     apache2-utils
Recommends:     python3-bcrypt
Recommends:     python3-systemd
BuildArch:      noarch
%sysusers_requires

%description
Radicale is a server for CalDAV (calendars, to-do lists) and CardDAV (contacts).

* Shares calendars and contact lists through CalDAV, CardDAV and HTTP.
* Supports events, todos, journal entries and business cards.
* Works out-of-the-box, no setup or configuration required.
* Can limit access by authentication.
* Can secure connections with TLS.
* Works with many CalDAV and CardDAV clients.
* Stores all data on the file system in a directory structure.
* Can be extended with plugins.

%prep
%autosetup
test -f setup.py || echo 'import setuptools; setuptools.setup()' > setup.py

%build
%python3_build
%sysusers_generate_pre %{SOURCE2} %{pkg_user_group} system-user-%{pkg_user_group}.conf

%install
%python3_install
install -m 0750 -d %{buildroot}%{pkg_config}/ %{buildroot}%{pkg_home}/
install -m 0640 config %{buildroot}%{pkg_config}/config
install -m 0755 -d %{buildroot}%{_sbindir}/
install -D -m 444 %{SOURCE1} %{buildroot}%{_unitdir}/%{pkg_name}.service
install -D -m 644 %{SOURCE3} %{buildroot}%{_prefix}/lib/firewalld/services/%{pkg_name}.xml

ln -sfv %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{pkg_name}

mkdir %{buildroot}%{pkg_home}/collections
%fdupes %{buildroot}%{python3_sitelib}

mkdir -p %{buildroot}%{_sysusersdir}
install -m 0644 %{SOURCE2} %{buildroot}%{_sysusersdir}/

%pre -f %{pkg_user_group}.pre
%service_add_pre %{pkg_name}.service

%post
test -e %{pkg_config}/rights || touch %{pkg_config}/rights
test -e %{pkg_config}/users  || touch %{pkg_config}/users
%service_add_post %{pkg_name}.service
%firewalld_reload

%preun
%service_del_preun %{pkg_name}.service

%postun
%service_del_postun %{pkg_name}.service

%files
%license COPYING.md
%doc CHANGELOG.md DOCUMENTATION.md README.md
%{_bindir}/%{pkg_name}
%{python3_sitelib}/%{name}-%{version}-py*.egg-info
%{python3_sitelib}/%{pkg_name}/
%{_sbindir}/rc%{pkg_name}
%{_unitdir}/%{pkg_name}.service
%config(noreplace) %attr(-,root,%{pkg_user_group}) %{pkg_config}/
%dir %attr(-,%{pkg_user_group},%{pkg_user_group}) %{pkg_home}/
%dir %attr(-,%{pkg_user_group},%{pkg_user_group}) %{pkg_home}/collections

# Register configuration files
%ghost %config(noreplace) %attr(660,%{pkg_user_group},%{pkg_user_group}) %{pkg_config}/rights
%ghost %config(noreplace) %attr(660,%{pkg_user_group},%{pkg_user_group}) %{pkg_config}/users

# User/group creation with sysusers.d(5)
%{_sysusersdir}/system-user-%{pkg_user_group}.conf

# Firewalld config
%dir %{_prefix}/lib/firewalld
%dir %{_prefix}/lib/firewalld/services
%{_prefix}/lib/firewalld/services/%{pkg_name}.xml

%changelog
* Wed Nov 27 2024 Ákos Szőts <szotsaki@gmail.com>
- Update to 3.3.1
  * Add: option [auth] type=dovecot
  * Add: option [server] protocol + ciphersuite for optional restrictions on SSL socket
  * Enhancement: log content in case of multiple main components error
  * Enhancement: [storage] hook documentation, logging, error behavior (no longer throwing an exception)
  * Fix: expand does not take timezones into account
  * Fix: expand does not support overridden recurring events
  * Fix: expand does not honor start and end times
- Update to 3.3.0
  * Adjustment: option [auth] htpasswd_encryption change default from "md5" to "autodetect"
  * Adjustment: switch from setup.py to pyproject.toml (but keep files for legacy packaging)
  * Adjustment: 'rights' file is now read only during startup
  * Add: option [auth] type=ldap with (group) rights management via LDAP/LDAPS
  * Add: option [rights] permit_overwrite_collection (default=True) which can be also controlled per collection by rights 'O' or 'o'
  * Enhancement: permit_delete_collection can be now controlled also per collection by rights 'D' or 'd'
  * Fix: only expand VEVENT on REPORT request containing 'expand'
  * Cleanup: Python 3.7 leftovers
* Fri Aug 30 2024 Ákos Szőts <szotsaki@gmail.com>
- Cleaned up unnecessary BuildRequires
- Update to 3.2.3
  * Add: support for Python 3.13
  * Fix: Using icalendar's tzinfo on created datetime to fix issue with icalendar
  * Fix: typos in code
  * Enhancement: Added free-busy report
  * Enhancement: Added 'max_freebusy_occurrences` setting to avoid potential DOS on reports
  * Enhancement: remove unexpected control codes from uploaded items
  * Enhancement: add 'strip_domain' setting for username handling
  * Enhancement: add option to toggle debug log of rights rule with doesn't match
  * Drop: remove unused requirement "typeguard"
  * Improve: Refactored some date parsing code
* Tue Jun 18 2024 Ákos Szőts <szotsaki@gmail.com>
- Update to 3.2.2
  * Enhancement: add support for auth.type=denyall (will be default for security reasons in upcoming releases)
  * Enhancement: display warning in case only default config is active
  * Enhancement: display warning in case no user authentication is active
  * Enhancement: add option to skip broken item to avoid triggering exception (default: enabled)
  * Enhancement: add support for predefined collections for new users
  * Enhancement: add options to enable several parts in debug log like backtrace, request_header, request_content, response_content (default: disabled)
  * Enhancement: rights/from_file: display resulting permission of a match in debug log
  * Enhancement: add Apache config file example (see contrib directory)
  * Fix: "verify-collection" skips non-collection directories, logging improved
* Fri Jun  7 2024 Ákos Szőts <szotsaki@gmail.com>
- Filtered out false positive rpmlint error message
- Update to 3.2.1
  * Enhancement: add option for logging bad PUT request content
  * Enhancement: extend logging with step where bad PUT request failed
  * Fix: support for recurrence "full day"
  * Fix: list of web_files related to HTML pages
  * Test: update/adjustments for workflows (pytest>=7, typeguard<4.3)
* Sun May  5 2024 Ákos Szőts <szotsaki@gmail.com>
- Update to 3.2.0
  * Enhancement: add hook support for event changes+deletion hooks (initial support: "rabbitmq")
  * Dependency: pika >= 1.1.0
  * Enhancement: add support for webcal subscriptions
  * Enhancement: major update of WebUI (design+features)
  * Adjust: change default loglevel to "info"
  * Enhancement: support "expand-property" on REPORT request
  * Drop: support for Python 3.7 (EOSL, can't be tested anymore)
  * Fix: allow quoted-printable encoding for vObjects
* Mon Mar 18 2024 Ákos Szőts <szotsaki@gmail.com>
- Update to 3.1.9
  * Add: support for Python 3.11 + 3.12
  * Drop: support for Python 3.6
  * Fix: MOVE in case listen on non-standard ports or behind reverse proxy
  * Fix: stricter requirements of Python 3.11
  * Fix: HTML pages
  * Fix: Main Component is missing when only recurrence id exists
  * Fix: passlib don't support bcrypt>=4.1
  * Fix: web login now proper encodes passwords containing %%XX (hexdigits)
  * Enhancement: user-selectable log formats
  * Enhancement: autodetect logging to systemd journal
  * Enhancement: test code
  * Enhancement: option for global permit to delete collection
  * Enhancement: auth type 'htpasswd' supports now 'htpasswd_encryption' sha256/sha512 and "autodetect" for smooth transition
  * Improve: Dockerfiles
  * Improve: server socket listen code + address format in log
  * Update: documentations + examples
  * Dependency: limit typegard version < 3
  * General: code cosmetics
* Sun Jan 15 2023 Ákos Szőts <szotsaki@gmail.com>
- Security fortifications (provided by systemd)
* Thu Jul 14 2022 Ákos Szőts <szotsaki@gmail.com>
- Update to 3.1.8
  * Fix setuptools requirement if installing wheel
  * Tests: Switch from python setup.py test to tox
  * Small changes to build system configuration and tests
* Wed Jun 22 2022 Ákos Szőts <szotsaki@gmail.com>
- Add python passlib as a recommendation as it is needed for
  htpasswd authentication
* Mon Jun 13 2022 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from descriptions.
* Mon Apr 25 2022 Ákos Szőts <szotsaki@gmail.com>
- Update to 3.1.7
  * Fix random href fallback
* Tue Apr 19 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.1.6:
  * Ignore 'Not a directory' error for optional config paths
  * Fix upload of whole address book/calendar with UIDs that collide on
    case-insensitive filesystem
* Tue Feb  8 2022 Ákos Szőts <szotsaki@gmail.com>
- Update to 3.1.5
  * Ignore configuration file if access is denied
  * Use F_FULLFSYNC with PyPy on MacOS
  * Fallback if F_FULLFSYNC is not supported by the filesystem
* Tue Feb  1 2022 Ákos Szőts <szotsaki@gmail.com>
- Update to 3.1.4
  * Fallback if RENAME_EXCHANGE is not supportd by the filesystem
  * Assume POSIX compatibility if sys.platform is not win32
* Wed Jan 26 2022 Ákos Szőts <szotsaki@gmail.com>
- Update to 3.1.3
  * Redirect '…/.well-known/caldav' and '…/.well-known/carddav' to base prefix
  * Warning instead of error when base prefix ends with '/'
* Sat Jan 22 2022 Ákos Szőts <szotsaki@gmail.com>
- Update to 3.1.2
  * Verify that base prefix starts with '/' but doesn't end with '/'
  * Improve base prefix log message
  * Never send body for HEAD requests (again)
* Wed Jan 19 2022 Ákos Szőts <szotsaki@gmail.com>
- Minimum Python version changed from 3.6.0 to 3.6 to be able to
  compile it on Leap 15.3 and 15.2
- Update to 3.1.1
  * Workaround for contact photo bug in InfCloud
  * Redirect GET and HEAD requests under /.web to sanitized path
  * Set Content-Length header for HEAD requests
  * Never send body for HEAD requests
  * Improve error messages for from_file rights backend
  * Don't sanitize WSGI script name
* Mon Jan  3 2022 Ákos Szőts <szotsaki@gmail.com>
- Fix download URL
  * This release contains a "v" in front of the version number
    in the URL
* Mon Dec 27 2021 Ákos Szőts <szotsaki@gmail.com>
- Update to 3.1.0
  * Single <D:propstat> element in PROPPATCH response
  * Allow multiple <D:set> and <D:remove> elements
  * Improve log messages
  * Fix date filter
  * Improve sanitization of collection properties
  * Cancel mkcalendar request on error
  * Use renameat2 on Linux for atomic overwriting of collections
  * Command Line Parser
  * Disallow abbreviated arguments
  * Support backend specific options and HTTP headers
  * Optional argument for boolean options
  * Load no config file for --config without argument
  * Allow float for server->timeout setting
  * Fix is-not-defined filter in addressbook-query report
  * Add python type hints
  * Add multifilesystem_nolock storage
  * Add support for Python 3.9 and 3.10
  * Drop support for Python 3.5
  * Fix compatibility with Evolution (Exceptions from recurrence rules)
* Tue Sep 28 2021 Thorsten Kukuk <kukuk@suse.com>
- system-user-radicale.conf: remove leading spaces, SLE15 does
  not like them [bsc#1190203]
* Sun Aug 22 2021 Ákos Szőts <szotsaki@gmail.com>
- Add firewalld service description for Radicale
  Based on the previous work of Martin Haas <sandrick@seznam.cz>
* Sun Aug 22 2021 Ákos Szőts <szotsaki@gmail.com>
- Migrate legacy user creation to sysusers.d(5)
* Sat Jun 19 2021 Ákos Szőts <szotsaki@gmail.com>
- Fix error message "Address family for hostname not supported" (EAFNOSUPPORT)
  when trying to bind to a non-loopback address during startup
* Sat Apr  3 2021 Ákos Szőts <szotsaki@gmail.com>
- Remove code for v1 -> v2/v3 upgrading since v1 times are long gone
* Thu Dec 10 2020 Ákos Szőts <szotsaki@gmail.com>
- Remove %%{?systemd_requires} macro as it is not always needed
- Give full path of the interpreter in the .service file as a security hardening
- URL update for upgrading from v1.x
* Thu Oct  8 2020 Ákos Szőts <szotsaki@gmail.com>
- Removed Radicale.logrotate since there's no /var/log/radicale anymore
* Tue Sep 15 2020 Ákos Szőts <szotsaki@gmail.com>
- Radicale 3.0.6
  * Allow web plugins to handle POST requests
- Remove /var/log/radicale since it's become unused by now
- Remove duplicated rights and users file listings
- Add DOCUMENTATION.md into %%doc
* Fri Sep 11 2020 Ákos Szőts <szotsaki@gmail.com>
- Start using openSUSE built-in python packaging scripts
- Wait with startup until network comes online. This helps the
  situation where a non-localhost address is given to be listened on
- Updated package description
* Tue Sep  8 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.0.5
  * Start storage hook in own process group
  * Kill storage hook on error or exit
  * Try to kill child processes of storage hook
  * Internal Server: Exit immediately when signal is received
    (do not wait for clients or storage hook to finish)
* Fri Aug 21 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.0.4
  * small fixes
* Mon May 25 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.0.2
  * Use 403 response for supported-report and valid-sync-token errors
  * Internal server: Handle missing IPv6 support
  * Fix XML error messages
* Wed May 20 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.0.0
  * Parallel write requests
  * Support PyPy
  * Protect against XML denial-of-service attacks
  * Check for duplicated UIDs in calendars/address books
  * Only add missing UIDs for uploaded whole calendars/address books
  * Switch from md5 to sha256 for UIDs and tokens
  * Code cleanup
  * Multiple configuration files separated by :
  * Optional configuration files by prepending file path with ?
  * Check validity of every configuration file and command line arguments separately
  * Bind to IPv4 and IPv6 address, when both are available for hostname
  * Set default address to localhost:5232
  * Remove settings for SSL ciphers and protocol versions (enforce safe defaults instead)
  * Remove settings for file locking because they are of little use
  * Remove daemonization
  * Use md5 as default for htpasswd_encryption setting
  * Move setting realm from section server to auth
  * Use permissions RW for non-leaf collections and rw for address books/calendars
  * New permission i that only allows access with HTTP method GET
  See https://github.com/Kozea/Radicale/blob/master/NEWS.md for more info.
* Thu Nov 29 2018 Ákos Szőts <szotsaki@gmail.com>
- Added python3-systemd for direct systemd journal logging
- Upgrade messages from 1 to 2 now appear in update logs and shown after transaction
- Radicale 2.1.11
  * Fix moving items between collections
* Wed Aug 29 2018 szotsaki@gmail.com
- Radicale 2.1.10
  * Update required versions for dependencies
  * Get RADICALE_CONFIG from WSGI environ
  * Improve HTTP status codes
  * Fix race condition in storage lock creation
  * Raise default limits for content length and timeout
  * Log output from hook
* Sun Apr 22 2018 szotsaki@gmail.com
- Radicale 2.1.9
  * Specify versions for dependencies
  * Move WSGI initialization into module
  * Check if REPORT method is actually supported
  * Include rights file in source distribution
  * Specify md5 and bcrypt as extras
  * Improve logging messages
  * Windows: Fix crash when item path is a directory
* Sun Sep 24 2017 szotsaki@gmail.com
- Radicale 2.1.8
  * Flush files before fsync'ing
- Radicale 2.1.7
  * Don't print warning when cache format changes
  * Add documentation for BaseAuth
  * Add is_authenticated2(login, user, password) to BaseAuth
  * Fix names of custom properties in PROPFIND requests with D:propname or D:allprop
  * Return all properties in PROPFIND requests with D:propname or D:allprop
  * Allow D:displayname property on all collections
  * Answer with D:unauthenticated for D:current-user-principal property when not logged in
  * Remove non-existing ICAL:calendar-color and C:calendar-timezone properties from PROPFIND requests with D:propname or D:allprop
  * Add D:owner property to calendar and address book objects
  * Remove D:getetag and D:getlastmodified properties from regular collections
* Sat Sep 16 2017 szotsaki@gmail.com
- Radicale 2.1.6
  * Fix content-type of VLIST
  * Specify correct COMPONENT in content-type of VCALENDAR
  * Cache COMPONENT of calendar objects (improves speed with some clients)
  * Stricter parsing of filters
  * Improve support for CardDAV filter
  * Fix some smaller bugs in CalDAV filter
  * Add X-WR-CALNAME and X-WR-CALDESC to calendars downloaded via HTTP/WebDAV
  * Use X-WR-CALNAME and X-WR-CALDESC from calendars published via WebDAV
* Mon Aug 28 2017 szotsaki@gmail.com
- Radicale 2.1.5
  * Add --verify-storage command-line argument
  * Allow comments in the htpasswd file
  * Don't strip whitespaces from user names and passwords in the htpasswd file
  * Remove cookies from logging output
  * Allow uploads of whole collections with many components
  * Show warning message if server.timeout is used with Python < 3.5.2
* Mon Aug  7 2017 szotsaki@gmail.com
- Radicale 2.1.4
  * Fix incorrect time range matching and calculation for some edge-cases with rescheduled recurrences
  * Fix owner property
- Radicale 2.1.3
  * Enable timeout for SSL handshakes and move them out of the main thread
  * Create cache entries during upload of items
  * Stop built-in server on Windows when Ctrl+C is pressed
  * Prevent slow down when multiple requests hit a collection during cache warm-up
* Tue Jul 25 2017 szotsaki@gmail.com
- Radicale 2.1.2
  * Remove workarounds for bugs in VObject < 0.9.5
  * Error checking of collection tags and associated components
  * Improve error checking of uploaded collections and components
  * Don't delete empty collection properties implicitly
  * Improve logging of VObject serialization
* Sat Jul  1 2017 szotsaki@gmail.com
- Radicale 2.1.1
  * Add missing UIDs instead of failing
  * Improve error checking of calendar and address book objects
  * Fix upload of whole address books
- Radicale 2.1.0
  * Built-in web interface for creating and managing address books and calendars
  * can be extended with web plugins
  * Much faster storage backend
  * Significant reduction in memory usage
  * Improved logging
  * Include paths (of invalid items / requests) in log messages
  * Include configuration values causing problems in log messages
  * Log warning message for invalid requests by clients
  * Log error message for invalid files in the storage backend
  * No stack traces unless debugging is enabled
  * Time range filter also regards overwritten recurrences
  * Items that couldn't be filtered because of bugs in VObject are always
    returned (and a warning message is logged)
  * Basic error checking of configuration files
  * File system locking isn't disabled implicitly anymore, instead a new
    configuration option gets introduced
  * The permissions of the lock file are not changed anymore
  * Support for sync-token
  * Support for client-side SSL certificates
  * Rights plugins can decide if access to an item is granted explicitly
  * Respond with 403 instead of 404 for principal collections of non-existing
    users when ``owner_only`` plugin is used (information leakage)
  * Authentication plugins can provide the login and password from the
    environment
  * new ``remote_user`` plugin, that gets the login from the ``REMOTE_USER``
    environment variable (for WSGI server)
  * new ``http_x_remote_user`` plugin, that gets the login from the
    ``X-Remote-User`` HTTP header (for reverse proxies)
- Radicale 2.0.0
  * Support Python 3.3+ only, Python 2 is not supported anymore
  * Keep only one simple filesystem-based storage system
  * Remove built-in Git support
  * Remove built-in authentication modules
  * Keep the WSGI interface, use Python HTTP server by default
  * Use a real iCal parser, rely on the "vobject" external module
  * Add a solid calendar discovery
  * Respect the difference between "files" and "folders", don't rely on slashes
  * Remove the calendar creation with GET requests
  * Be stateless
  * Use a file locker
  * Add threading
  * Get atomic writes
  * Support new filters
  * Support read-only permissions
  * Allow External plugins for authentication, rights management, storage and
    version control
* Mon Jun 26 2017 szotsaki@gmail.com
- Radicale 1.1.4
- Use shutil.move for --export-storage
* Sat May 27 2017 szotsaki@gmail.com
- Radicale 1.1.3
- Add a --export-storage=FOLDER command-line argument (by Unrud, see #606)
* Mon May  1 2017 szotsaki@gmail.com
- Radicale 1.1.2
- Security fix: Add a random timer to avoid timing oracles and simple bruteforce attacks when using the htpasswd authentication method.
- Various minor fixes.
* Thu Dec 15 2016 mrueckert@suse.de
- downgrade requires to recommends for apache2-utils. it is not
  really needed for all setups.
- add recommends for optional features:
  python3-dulwich -> git support
  python3-passlib + python3-bcrypt-> bcrypt support
* Sun Apr 24 2016 bosim@opensuse.org
- Removed _source and added actual tar ball source
- Added firewall config
- Added python3 requirement
* Fri Jan 15 2016 szotsaki@gmail.com
- Radicale 1.1.1
- Fix the owner_write rights rule
* Fri Jan  1 2016 szotsaki@gmail.com
- Radicale 1.1
- Improve the regex used for well-known URIs (by Unrud)
- Prevent regex injection in rights management (by Unrud)
- Prevent crafted HTTP request from calling arbitrary functions (by Unrud)
- Improve URI sanitation and conversion to filesystem path (by Unrud)
- Decouple the daemon from its parent environment (by Unrud)
- Assign new items to corret key (by Unrud)
- Avoid race condition in PID file creation (by Unrud)
- Improve the docker version (by cdpb)
- Encode message and commiter for git commits
- Test with Python 3.5
* Fri Sep 18 2015 szotsaki@gmail.com
- Radicale 1.0
- Enhanced performances (by Mathieu Dupuy)
- Add MD5-APR1 and BCRYPT for htpasswd-based authentication (by Jan-Philip Gehrcke)
- Use PAM service (by Stephen Paul Weber)
- Don't discard PROPPATCH on empty collections (Markus Unterwaditzer)
- Write the path of the collection in the git message (Matthew Monaco)
- Tests launched on Travis
* Wed Jan 21 2015 szotsaki@gmail.com
- Radicale 0.10
- Support well-known URLs (by Mathieu Dupuy)
- Fix collection discovery (by Markus Unterwaditzer)
- Reload logger config on SIGHUP (by Élie Bouttier)
- Remove props files when deleting a collection (by Vincent Untz)
- Support salted SHA1 passwords (by Marc Kleine-Budde)
- Don't spam the logs about non-SSL IMAP connections to localhost (by Giel van Schijndel)
* Fri Oct 24 2014 szotsaki@gmail.com
- Radicale 0.9
- Custom handlers for auth, storage and rights (by Sergey Fursov)
- 1-file-per-event storage (by Jean-Marc Martins)
- Git support for filesystem storages (by Jean-Marc Martins)
- DB storage working with PostgreSQL, MariaDB and SQLite (by Jean-Marc Martins)
- Clean rights manager based on regular expressions (by Sweil)
- Support of contacts for Apple's clients
- Support colors (by Jochen Sprickerhof)
- Decode URLs in XML (by Jean-Marc Martins)
- Fix PAM authentication (by Stepan Henek)
- Use consistent etags (by 9m66p93w)
- Use consistent sorting order (by dnnr)
- Return 401 on unauthorized DELETE requests (by Eduard Braun)
- Move pid file creation in child process (by Mathieu Dupuy)
- Allow requests without base_prefix (by jheidemann)
* Fri Aug  8 2014 szotsaki@gmail.com
- Adding missing config/log files and directories
- Adding logrotate script
- Fixing bnc#890094
* Fri Aug  8 2014 szotsaki@gmail.com
- Addressing an issue when creating new groups and users for Radicale (bnc#890093)
* Wed Sep 25 2013 szotsaki@gmail.com
- Radicale 0.8
- New authentication and rights management modules (by Matthias Jordan)
- Experimental database storage
- Command-line option for custom configuration file (by Mark Adams)
- Root URL not at the root of a domain (by Clint Adams, Fabrice Bellet, Vincent Untz)
- Improved support for iCal, CalDAVSync, CardDAVSync, CalDavZAP and CardDavMATE
- Empty PROPFIND requests handled (by Christoph Polcin)
- Colon allowed in passwords
- Configurable realm message
* Thu Sep 27 2012 szotsaki@gmail.com
- branch from mrueckert version (thank you for the .spec file)
- Radicale 0.7.1
- Many address books fixes
- New IMAP ACL (by Daniel Aleksandersen)
- PAM ACL fixed (by Daniel Aleksandersen)
- Courier ACL fixed (by Benjamin Frank)
- Always set display name to collections (by Oskari Timperi)
- Various DELETE responses fixed
* Thu Apr 21 2011 mrueckert@suse.de
- initial package (v0.5)
